@@ -21,6 +21,8 @@
 
 #include <glib-object.h>
 
+#include "gf-orientation-manager-private.h"
+
 G_BEGIN_DECLS
 
 typedef enum
@@ -50,10 +52,12 @@ gf_monitor_transform_is_flipped (GfMonitorTransform transform)
   return (transform >= GF_MONITOR_TRANSFORM_FLIPPED);
 }
 
-GfMonitorTransform gf_monitor_transform_invert    (GfMonitorTransform transform);
+GfMonitorTransform gf_monitor_transform_from_orientation (GfOrientation      orientation);
 
-GfMonitorTransform gf_monitor_transform_transform (GfMonitorTransform transform,
-                                                   GfMonitorTransform other);
+GfMonitorTransform gf_monitor_transform_invert           (GfMonitorTransform transform);
+
+GfMonitorTransform gf_monitor_transform_transform        (GfMonitorTransform transform,
+                                                          GfMonitorTransform other);
 
 G_END_DECLS
 
