@@ -374,15 +374,17 @@ static gboolean
 is_shift_pressed (void)
 {
 	gboolean ret;
+	GdkDisplay *display;
 	XkbStateRec state;
 	Bool status;
 
 	ret = FALSE;
+	display = gdk_display_get_default ();
 
-        gdk_error_trap_push ();
-	status = XkbGetState (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
+	gdk_x11_display_error_trap_push (display);
+	status = XkbGetState (GDK_DISPLAY_XDISPLAY (display),
 			      XkbUseCoreKbd, &state);
-        gdk_error_trap_pop_ignored ();
+	gdk_x11_display_error_trap_pop_ignored (display);
 
 	if (status == Success) {
 		ret = state.mods & ShiftMask;
@@ -580,6 +582,8 @@ autorun_dialog_response (GtkDialog *dialog, gint response, AutorunDialogData *da
 				data->open_window_func (data->mount, data->user_data);
 		}
 		break;
+	default:
+		break;
 	}
 
 	autorun_dialog_destroy (data);
