@@ -19,19 +19,18 @@
 #define GF_INPUT_SETTINGS_H
 
 #include <glib-object.h>
+#include "backends/gf-monitor-manager.h"
 
 G_BEGIN_DECLS
 
-typedef struct _FlashbackDisplayConfig FlashbackDisplayConfig;
-
 #define GF_TYPE_INPUT_SETTINGS gf_input_settings_get_type ()
 G_DECLARE_FINAL_TYPE (GfInputSettings, gf_input_settings,
                       GF, INPUT_SETTINGS, GObject)
 
-GfInputSettings *gf_input_settings_new                (void);
+GfInputSettings *gf_input_settings_new                 (void);
 
-void             gf_input_settings_set_display_config (GfInputSettings        *settings,
-                                                       FlashbackDisplayConfig *config);
+void             gf_input_settings_set_monitor_manager (GfInputSettings  *settings,
+                                                        GfMonitorManager *monitor_manager);
 
 G_END_DECLS
 
